@@ -1,5 +1,5 @@
 import { defineMessages, injectIntl } from 'react-intl';
-import React from 'react';
+import React, { PropTypes } from 'react';
 
 import DriverFields from './DriverFields';
 
@@ -8,10 +8,6 @@ const messages = defineMessages({
     id: 'PXEAndSSHDriverFields.addr_title',
     defaultMessage: 'SSH IP Address or FQDN'
   },
-  port_title: {
-    id: 'PXEAndSSHDriverFields.port_title',
-    defaultMessage: 'SSH Port'
-  },
   user_title: {
     id: 'PXEAndSSHDriverFields.user_title',
     defaultMessage: 'SSH User'
@@ -25,19 +21,16 @@ const messages = defineMessages({
 class PXEAndSSHDriverFields extends React.Component {
   render() {
     return (
-      <DriverFields
-        {...this.props}
-        addr_title={this.props.intl.formatMessage(messages.addr_title)}
-        user_title={this.props.intl.formatMessage(messages.user_title)}
-        port_title={this.props.intl.formatMessage(messages.port_title)}
-        pwd_title={this.props.intl.formatMessage(messages.pwd_title)}
-      />
+      <DriverFields {...this.props}
+                    addr_title={this.props.intl.formatMessage(messages.addr_title)}
+                    user_title={this.props.intl.formatMessage(messages.user_title)}
+                    pwd_title={this.props.intl.formatMessage(messages.pwd_title)} />
     );
   }
 }
 
 PXEAndSSHDriverFields.propTypes = {
-  intl: React.PropTypes.object
+  intl: PropTypes.object
 };
 
 export default injectIntl(PXEAndSSHDriverFields);
